@@ -45,6 +45,8 @@
 #include "plugin.h"
 #include "strutl.h"
 
+#include "cdebconf_text.h"
+
 #include <ctype.h>
 #include <fcntl.h>
 #include <signal.h>
@@ -66,10 +68,6 @@ typedef int (text_handler)(struct frontend *obj, struct question *q);
 
 #define MAKE_UPPER(C) do { if (islower((int) C)) { C = (char) toupper((int) C); } } while(0)
 
-#define CHAR_GOBACK '<'
-#define CHAR_HELP '?'
-#define CHAR_CLEAR '!'
-
 #if defined(__s390__) || defined (__s390x__)
 #define ISEMPTY(buf) (buf[0] == 0 || (buf[0] == '.' && buf[1] == 0))
 #else
@@ -398,10 +396,8 @@ static void choices_delete(struct choices *c)
 				free(c->choices_translated[i]);
 			free(c->choices_translated);
 		}
-		if (c->selected)
-			free(c->selected);
-		if (c->tindex)
-			free(c->tindex);
+		free(c->selected);
+		free(c->tindex);
 		free(c);
 	}
 }
@@ -822,8 +818,7 @@ static int text_shutdown(struct frontend *obj)
 	struct frontend_data *data = (struct frontend_data *)obj->data;
 	if (NULL != data)
 	{
-		if (NULL != data->previous_title)
-			free(data->previous_title);
+		free(data->previous_title);
 		free(data);
 		obj->data = NULL;
 	}
@@ -935,8 +930,7 @@ static int text_go(struct frontend *obj)
 					underline[underline_len] = '\0';
 					printf("%s\n%s\n\n", obj->title, underline);
 					free(underline);
-					if (data->previous_title)
-						free(data->previous_title);
+					free(data->previous_title);
 					data->previous_title = strdup(obj->title);
 				}
 				text_handler_displaydesc(obj, q);
@@ -1012,13 +1006,13 @@ static void text_progress_stop(struct frontend *obj)
 
 struct frontend_module debconf_frontend_module =
 {
-	initialize: text_initialize,
-	shutdown: text_shutdown,
-	lookup_directive: text_lookup_directive,
-	can_go_back: text_can_go_back,
-	can_align: text_can_align,
-	go: text_go,
-	progress_start: text_progress_start,
-	progress_set: text_progress_set,
-	progress_stop: text_progress_stop,
+	.initialize = text_initialize,
+	.shutdown = text_shutdown,
+	.lookup_directive = text_lookup_directive,
+	.can_go_back = text_can_go_back,
+	.can_align = text_can_align,
+	.go = text_go,
+	.progress_start = text_progress_start,
+	.progress_set = text_progress_set,
+	.progress_stop = text_progress_stop,
 };
